@@ -170,7 +170,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.33'
+__version__ = '0.1.34'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -250,7 +250,8 @@ def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
     elif text.startswith('['):
         node_lit = text
     else:
-        parts = norm_line_sep(text).split("\n", maxsplit=1)
+        text = norm_line_sep(text)
+        parts = text.split("\n", maxsplit=1)
         if len(parts) == 2 and parts[1].startswith(('[', '{')):
             flow_path_text = parts[0]
             node_lit = parts[1] if parts[1][0] == '[' else "[" + parts[1] + "]"
